/* ========================================
 *
 * Copyright YOUR COMPANY, THE YEAR
 * All Rights Reserved
 * UNPUBLISHED, LICENSED SOFTWARE.
 *
 * CONFIDENTIAL AND PROPRIETARY INFORMATION
 * WHICH IS THE PROPERTY OF your company.
 *
 * ========================================
*/

#include "project.h"
#include <CyFlash.h>
#include <stdio.h>


#define CY_TEST_FLASH_ROW       (CY_FLASH_NUMBER_ROWS - 2u)                           //  global ID of the row of interest
#define CY_TEST_FLASH_ADDR      (CY_TEST_FLASH_ROW * CY_FLASH_SIZEOF_ROW)             //  address if the global row of interest
#define ARRAY_ID                ((uint8)(CY_TEST_FLASH_ROW / CY_FLASH_SIZEOF_ROW))    //  ID of the array that contains the row of interest
#define ARRAY_ID_ROW_ADDR       ((uint16)(CY_FLASH_SIZEOF_ROW - 2u))                  //  address offset of the row of interest


//------------------------------------------------------------------------------
//
void
flash_store( uint8* buf, uint16 sz )
{

#ifndef CY_PSOC5
    
    return;

#else

    if( sz > CYDEV_FLS_ROW_SIZE )  return;

    uint8 flash_row[ CYDEV_FLS_ROW_SIZE ];
    memmove( flash_row, buf, sz );
    
    cystatus ret = CYRET_SUCCESS;

    CySetTemp();
    ret = CyWriteRowData( ARRAY_ID, ARRAY_ID_ROW_ADDR, flash_row );

    if( ret != CYRET_SUCCESS )
    {
        Debug_PutString( "CyWriteRowData(...) failed\n\r\b" );
        //CyHalt( 0x00u );
        return;
    }
    
    
#endif  // (CY_PSOC5)

}


//------------------------------------------------------------------------------
//
void
flash_read( uint8* buf, uint16 sz )
{
#ifndef CY_PSOC5

    return;
    
#else
    
    uint16 i = 0;
    volatile uint8 flash_byte = 0;
    
    if( sz > CYDEV_FLS_ROW_SIZE )  return;

    
    for( i = 0u; i < sz; i++)
    {
        flash_byte = ( *( (uint8*) ( CYDEV_FLS_BASE + CY_TEST_FLASH_ADDR + i ) ) );
        buf[ i ] = flash_byte;
    }  
        
#endif
}


//------------------------------------------------------------------------------
//
int
main( void )
{
    CyGlobalIntEnable; /* Enable global interrupts. */
    
    Debug_Start();
    
    LED1_Write( 1 );
    LED2_Write( 0 );

    const static uint16 SZ = 8;
    uint8 buf1[] = { 0x0a, 0x0b, 0x0c, 0x0d, 0x01, 0x02, 0x03, 0x04 };
    uint8 buf2[] = { 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00 };

    Debug_ClearTxBuffer();

    Debug_PutString( "booted: " );
    
    flash_read( buf2, SZ );
    if( 0 == memcmp( buf2, buf1, SZ ) )
    {
        Debug_PutString( "data is stored\n\r\b" );
    }
    else
    {
        Debug_PutString( "data is not stored, storing ..." );
        flash_store( buf1, SZ );
        
            flash_read( buf2, SZ );
        if( 0 == memcmp( buf2, buf1, SZ ) )
        {
            Debug_PutString( " stored\n\r\b" );
        }
        else
        {
            Debug_PutString( " not stored\n\r\b" );
        }
    }

    


    
    
    
    
    
    
    for( ;; )
    {
        LED1_Write( ! LED1_Read() );
        LED2_Write( ! LED2_Read() );

        CyDelay( 250 );
        
    }
}

/* [] END OF FILE */
